@@ -97,8 +97,8 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
 
     code_epsg <- switch(emprise, #emprise
                         "FRM"="2154",# Lambert 93
-                        "971"="32620",# UTM 20 N
-                        "972"="32620",# UTM 20 N
+                        "971"="5490",# UTM 20 N
+                        "972"="5490",# UTM 20 N
                         "973"="2972",# UTM 22 N
                         "974"="2975",# UTM 40 S
                         "976"="4471")# UTM 38 S
@@ -218,6 +218,16 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
     if(is.null(xlim)) xlim <- c(st_bbox(fondMaille)$xmin,st_bbox(fondMaille)$xmax+x_marge*3)
     if(is.null(ylim)) ylim <- c(st_bbox(fondMaille)$ymin,st_bbox(fondMaille)$ymax+y_marge*3)
 
+    x_large <- (xlim[2]-xlim[1])/20
+    y_large <- x_large/1.5
+
+    xmin <- min(st_coordinates(fond_leg_ronds)[,1]) - x_large
+    xmax <- max(st_coordinates(fond_leg_ronds)[,1]) + (x_large*3)
+    ymin <- min(st_coordinates(fond_leg_ronds)[,2]) - y_large
+    ymax <- max(st_coordinates(fond_leg_ronds)[,2]) + (y_large*3)
+    bbox_leg_ronds <- matrix(c(xmin,ymax, xmax,ymax, xmax,ymin, xmin,ymin, xmin,ymax),ncol=2, byrow=TRUE)
+    bbox_leg_ronds <- st_sf(geometry=st_sfc(st_polygon(list(bbox_leg_ronds))),crs=st_crs(fondMaille))
+
     par(mai=c(0,0,0,0))
     plot(st_geometry(fondMaille),xlim=xlim,ylim=ylim,border=colBorderMaille)
 
@@ -238,12 +248,6 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
     if(nrow(fond_ronds_pos)>0) plot(st_geometry(fond_ronds_pos),border=colBorder,col=colPos,add=T)
     if(nrow(fond_ronds_neg)>0) plot(st_geometry(fond_ronds_neg),border=colBorder,col=colNeg,add=T)
 
-    plot(st_geometry(fond_leg_ronds),add=T,col="transparent",border="black")
-    text(pts2_grand_pl[1]+1000,pts2_grand_pl[2],labels=round(max_var,precisionLegRonds),cex=0.9,adj=0)
-    text(pts2_petit_pl[1]+1000,pts2_petit_pl[2],labels=round(max_var/3,precisionLegRonds),cex=0.9,adj=0)
-
-    text(min(st_coordinates(fond_leg_ronds[1,])[,1]),max(st_coordinates(fond_leg_ronds[1,])[,2])+(st_bbox(fondMaille)$xmax-st_bbox(fondMaille)$xmin)/20,labels=titreLeg,cex=1,adj=0)
-
     if(!is.null(fondSurAnalyse))
     {
       for(i in 1:length(fondSurAnalyse))
@@ -264,6 +268,14 @@ function(data,fondMaille,fondSousAnalyse=NULL,fondSurAnalyse=NULL,idData,varVolu
       }
     }
 
+    suppressWarnings(plot(bbox_leg_ronds,add=T,col="white",border="white",lwd=1))
+
+    plot(st_geometry(fond_leg_ronds),add=T,col="transparent",border="black")
+    text(pts2_grand_pl[1]+1000,pts2_grand_pl[2],labels=round(max_var,precisionLegRonds),cex=0.9,adj=0)
+    text(pts2_petit_pl[1]+1000,pts2_petit_pl[2],labels=round(max_var/3,precisionLegRonds),cex=0.9,adj=0)
+
+    text(min(st_coordinates(fond_leg_ronds[1,])[,1]),max(st_coordinates(fond_leg_ronds[1,])[,2])+(st_bbox(fondMaille)$xmax-st_bbox(fondMaille)$xmin)/20,labels=titreLeg,cex=1,adj=0)
+
     if(titreCarte!="")
     {
       text(((st_bbox(fondMaille)$xmax+x_marge*3)-st_bbox(fondMaille)$xmin)/2,st_bbox(fondMaille)$ymax+y_marge*3,labels=titreCarte)
